@@ -7,17 +7,15 @@
 void log_real_(pid_t tid, const char *tag, const char *format, ...)
 {
     va_list args;
-    float t;
+    char datestr[13]; /* HH:MM:SS.mmm */
     va_start(args, format);
     {
-        struct timespec ts;
-        clock_gettime(CLOCK_MONOTONIC, &ts);
-        t = (ts.tv_sec * 1.0f) + (ts.tv_nsec * 0.000000001f);
+        struct timeval tv;
+        gettimeofday(&tv, NULL);
+        strftime(datestr, 13, "%H:%M:%S", localtime(&tv.tv_sec));
+        sprintf(datestr+8, ".%03d", tv.tv_usec / 1000);
     }
-    if(tag != NULL)
-        fprintf(stderr, "[REPROZIP] %f %s: ", t, tag);
-    else
-        fprintf(stderr, "[REPROZIP] %f ", t);
+    fprintf(stderr, "[REPROZIP] %s %s: ", datestr, tag);
     if(tid > 0)
         fprintf(stderr, "[%d] ", tid);
     vfprintf(stderr, format, args);
