@@ -19,14 +19,18 @@ static long tracee_getword(pid_t tid, const void *addr)
     res = ptrace(PTRACE_PEEKDATA, tid, addr, NULL);
     if(errno)
     {
+        /* LCOV_EXCL_START : We only do that on things that went through the
+         * kernel successfully, and so should be valid. The exception is
+         * execve(), which will dup arguments when entering the syscall */
         log_error_(tid, "tracee_getword() failed: ");
         perror(NULL);
         return 0;
+        /* LCOV_EXCL_END */
     }
     return res;
 }
 
-static void *tracee_getptr(int mode, pid_t tid, const void *addr)
+void *tracee_getptr(int mode, pid_t tid, const void *addr)
 {
     if(mode == MODE_I386)
     {
@@ -44,6 +48,34 @@ static void *tracee_getptr(int mode, pid_t tid, const void *addr)
     }
 }
 
+uint64_t tracee_getlong(int mode, pid_t tid, const void *addr)
+{
+    if(mode == MODE_I386)
+    {
+        /* Longs are 32 bits */
+        uint32_t val;
+        tracee_read(tid, (void*)&val, addr, sizeof(val));
+        return (uint64_t)val;
+    }
+    else /* mode == MODE_X86_64 */
+    {
+        /* Longs are 64 bits */
+        uint64_t val;
+        tracee_read(tid, (void*)&val, addr, sizeof(val));
+        return val;
+    }
+}
+
+size_t tracee_getwordsize(int mode)
+{
+    if(mode == MODE_I386)
+        /* Pointers are 32 bits */
+        return 4;
+    else /* mode == MODE_X86_64 */
+        /* Pointers are 64 bits */
+        return 8;
+}
+
 size_t tracee_strlen(pid_t tid, const char *str)
 {
     uintptr_t ptr = (uintptr_t)str;
