@@ -384,9 +384,11 @@ static int syscall_execve_out(const char *name, struct Process *process,
         }
         if(exec_process == NULL)
         {
+            /* LCOV_EXCL_START : internal error */
             log_critical(process->tid,
                          "execve() completed but call wasn't recorded");
             return -1;
+            /* LCOV_EXCL_END */
         }
         execi = exec_process->syscall_info;
 
@@ -466,10 +468,12 @@ static int syscall_forking(const char *name, struct Process *process,
             /* Process has been seen before and options were set */
             if(new_process->status != PROCESS_UNKNOWN)
             {
+                /* LCOV_EXCL_START : internal error */
                 log_critical(new_tid,
                              "just created process that is already running "
                              "(status=%d)", new_process->status);
                 return -1;
+                /* LCOV_EXCL_END */
             }
             new_process->status = PROCESS_ATTACHED;
             ptrace(PTRACE_SYSCALL, new_process->tid, NULL, NULL);
@@ -546,12 +550,23 @@ static int handle_connect(struct Process *process,
 static int syscall_socketcall(const char *name, struct Process *process,
                               unsigned int udata)
 {
+    /* Argument 1 is an array of longs, which are either numbers of pointers */
+    uint64_t args = process->params[1].u;
+    /* Size of each element in the array */
+    const size_t wordsize = tracee_getwordsize(process->mode);
+    /* Note that void* pointer arithmetic is illegal, hence the uint */
     if(process->params[0].u == SYS_ACCEPT)
         return handle_accept(process,
-                             process->params[2].p, process->params[3].p);
+                             tracee_getptr(process->mode, process->tid,
+                                           (void*)(args + 1*wordsize)),
+                             tracee_getptr(process->mode, process->tid,
+                                           (void*)(args + 2*wordsize)));
     else if(process->params[0].u == SYS_CONNECT)
         return handle_connect(process,
-                              process->params[2].p, process->params[3].u);
+                              tracee_getptr(process->mode, process->tid,
+                                            (void*)(args + 1*wordsize)),
+                              tracee_getlong(process->mode, process->tid,
+                                             (void*)(args + 2*wordsize)));
     else
         return 0;
 }
@@ -915,9 +930,11 @@ int syscall_handle(struct Process *process)
     }
     else if(process->current_syscall & __X32_SYSCALL_BIT)
     {
+        /* LCOV_EXCL_START : x32 is not supported right now */
         syscall_type = SYSCALL_X86_64_x32;
         if(verbosity >= 4)
             log_info(process->tid, "syscall %d (x32)", syscall);
+        /* LCOV_EXCL_END */
     }
     else
     {
