@@ -134,8 +134,8 @@ def testrun(args):
             argv = [args.arg0] + args.cmdline[1:]
         else:
             argv = args.cmdline
-        logging.debug("Starting tracer, binary=%r, argv=%r" % (
-                      args.cmdline[0], argv))
+        logging.debug("Starting tracer, binary=%r, argv=%r",
+                      args.cmdline[0], argv)
         c = _pytracer.execute(args.cmdline[0], argv, database.path,
                               args.verbosity)
         print("\n\n-----------------------------------------------------------"
@@ -189,12 +189,12 @@ def pack(args):
     target = Path(args.target)
     if not target.unicodename.lower().endswith('.rpz'):
         target = Path(target.path + '.rpz')
-        logging.warning("Changing output filename to %s" % target.unicodename)
+        logging.warning("Changing output filename to %s", target.unicodename)
     reprozip.pack.pack(target, Path(args.dir), args.identify_packages)
 
 
 def main():
-    """Entry point when called on the command line.
+    """Entry point when called on the command-line.
     """
     # Locale
     locale.setlocale(locale.LC_ALL, '')
@@ -202,8 +202,11 @@ def main():
     # Encoding for output streams
     if str == bytes:  # PY2
         writer = codecs.getwriter(locale.getpreferredencoding())
+        o_stdout, o_stderr = sys.stdout, sys.stderr
         sys.stdout = writer(sys.stdout)
+        sys.stdout.buffer = o_stdout
         sys.stderr = writer(sys.stderr)
+        sys.stderr.buffer = o_stderr
 
     # http://bugs.python.org/issue13676
     # This prevents reprozip from reading argv and envp arrays from trace
