@@ -30,6 +30,8 @@ from reprozip.utils import PY3, izip, itervalues, listvalues, unicode_, \
 
 
 class TracedFile(File):
+    """Override of `~reprozip.common.File` that reads stats from filesystem.
+    """
     #                               read
     #                              +------+
     #                              |      |
@@ -197,8 +199,8 @@ def get_files(conn):
         logging.warning(
                 "Some files were read and then written. We will only pack the "
                 "final version of the file; reproducible experiments "
-                "shouldn't change their input files:\n%s" %
-                ", ".join(unicode_(fi.path for fi in read_then_written_files)))
+                "shouldn't change their input files:\n%s",
+                ", ".join(unicode_(fi.path) for fi in read_then_written_files))
 
     files = set(
             fi
@@ -209,6 +211,11 @@ def get_files(conn):
 
 
 def list_directories(conn):
+    """Gets additional needed directories from the trace database.
+
+    Returns the directories which are used as a process's working directory or
+    in which files are created.
+    """
     cur = conn.cursor()
     executed_files = cur.execute(
             '''
@@ -228,6 +235,8 @@ def list_directories(conn):
 
 
 def merge_files(newfiles, newpackages, oldfiles, oldpackages):
+    """Merges two sets of packages and files.
+    """
     files = set(oldfiles)
     files.update(newfiles)
 
@@ -263,13 +272,13 @@ def trace(binary, argv, directory, append, verbosity=1):
     # Trace directory
     if not append:
         if directory.exists():
-            logging.info("Removing existing directory %s" % directory)
+            logging.info("Removing existing directory %s", directory)
             directory.rmtree()
         directory.mkdir(parents=True)
     else:
         if not directory.exists():
             logging.warning("--continue was specified but %s does not exist "
-                            "-- creating" % directory)
+                            "-- creating", directory)
             directory.mkdir(parents=True)
 
     # Runs the trace
@@ -280,13 +289,15 @@ def trace(binary, argv, directory, append, verbosity=1):
     if c != 0:
         if c & 0x0100:
             logging.warning("Program appears to have been terminated by "
-                            "signal %d" % (c & 0xFF))
+                            "signal %d", c & 0xFF)
         else:
-            logging.warning("Program exited with non-zero code %d" % c)
+            logging.warning("Program exited with non-zero code %d", c)
     logging.info("Program completed")
 
 
 def write_configuration(directory, sort_packages, overwrite=False):
+    """Writes the canonical YAML configuration file.
+    """
     database = directory / 'trace.sqlite3'
 
     if PY3:
@@ -320,6 +331,7 @@ def write_configuration(directory, sort_packages, overwrite=False):
         runs, oldpkgs, oldfiles, patterns = load_config(config,
                                                         canonical=False,
                                                         File=TracedFile)
+        # Here, additional patterns are discarded
 
         executions = cur.execute(
                 '''
@@ -346,7 +358,7 @@ def write_configuration(directory, sort_packages, overwrite=False):
                 ORDER BY p.id;
                 ''')
     for ((r_name, r_argv, r_envp, r_workingdir, r_exitcode),
-            input_files, output_files) in (izip(executions, inputs, outputs)):
+            input_files, output_files) in izip(executions, inputs, outputs):
         # Decodes command-line
         argv = r_argv.split('\0')
         if not argv[-1]:
@@ -358,7 +370,7 @@ def write_configuration(directory, sort_packages, overwrite=False):
             envp = envp[:-1]
         environ = dict(v.split('=', 1) for v in envp)
 
-        # Gets files from command line
+        # Gets files from command-line
         command_line_files = {}
         for i, arg in enumerate(argv):
             p = Path(r_workingdir, arg).resolve()
@@ -374,7 +386,7 @@ def write_configuration(directory, sort_packages, overwrite=False):
         # Labels input files
         input_files_dict = {}
         for in_file in input_files:
-            # If file is on the command line
+            # If file is on the command-line
             if in_file in command_line_files:
                 if input_files_on_cmdline > 1:
                     label = "arg_%d" % command_line_files[in_file]
@@ -391,12 +403,12 @@ def write_configuration(directory, sort_packages, overwrite=False):
                 uniquelabel = '%s_%d' % (label, i)
             input_files_dict[uniquelabel] = str(in_file)
         # TODO : Note that right now, we keep as input files the ones that
-        # don't appear on the command line
+        # don't appear on the command-line
 
         # Labels output files
         output_files_dict = {}
         for out_file in output_files:
-            # If file is on the command line
+            # If file is on the command-line
             if out_file in command_line_files:
                 if output_files_on_cmdline > 1:
                     label = "arg_%d" % command_line_files[out_file]
@@ -413,7 +425,7 @@ def write_configuration(directory, sort_packages, overwrite=False):
                 uniquelabel = '%s_%d' % (label, i)
             output_files_dict[uniquelabel] = str(out_file)
         # TODO : Note that right now, we keep as output files the ones that
-        # don't appear on the command line
+        # don't appear on the command-line
 
         runs.append({'binary': r_name, 'argv': argv,
                      'workingdir': Path(r_workingdir).path,
